@@ -124,7 +124,7 @@ def convert_from_process_graph(
         return evalscripts
 
 
-def generate_nodes_from_process_graph(process_graph, bands_dimension_name, temporal_dimension_name, level=1, node_varname_prefix="node_"):
+def generate_nodes_from_process_graph(process_graph, bands_dimension_name, temporal_dimension_name, level=1):
     dependency_graph = get_dependencies(process_graph)
     dependents = get_dependents(dependency_graph)
     execution_order = get_execution_order(dependency_graph, dependents)
@@ -148,7 +148,7 @@ def generate_nodes_from_process_graph(process_graph, bands_dimension_name, tempo
 
         if process_id == "load_collection":
             input_bands = arguments["bands"]
-            initial_data_name = node_varname_prefix + node_id
+            initial_data_name = "node_" + node_id
             continue
         elif process_id == "save_result":
             continue
@@ -159,7 +159,13 @@ def generate_nodes_from_process_graph(process_graph, bands_dimension_name, tempo
                 temporal_dimension_name,
                 level=level + 1,
             )
-
+        elif process_id == "apply":
+            child_nodes, _, _ = generate_nodes_from_process_graph(
+                arguments["process"]["process_graph"],
+                bands_dimension_name,
+                temporal_dimension_name,
+                level=level + 1,
+            )
         node = Node(
             node_id,
             process_id,
