@@ -120,6 +120,9 @@ class DataCube {
         const labels = this.dimensions[axis].labels
 
         while (true) {
+            if (coords[currInd] === null) {
+                currInd++
+            }
             if (currInd >= shape.length) {
                 break;
             }
@@ -131,11 +134,9 @@ class DataCube {
             newData = this._set(newData, newVals, coords)
             if (coords[currInd] + 1 >= shape[currInd]) {
                 currInd++
+            } else {
+                coords[currInd]++
             }
-            if (coords[currInd] === null) {
-                currInd++
-            }
-            coords[currInd]++
         }
         const finalSelectCoords = new Array(shape.length).fill(null);
         finalSelectCoords[axis] = 0;
@@ -212,4 +213,9 @@ class DataCube {
         }
         return this._iter(arr, exec_filter)
     }
+
+    apply(process) {
+      const newData = this._iter(this.data, x=>process({"x": x}));
+      this.data = newData;
+    }
 }
\ No newline at end of file
