@@ -30,14 +30,13 @@ class Node:
         dependents,
         level,
         process_definitions_directory="javascript_processes",
-        node_varname_prefix="node_"
     ):
         self.set_appropriate_class(process_id)
         self.variable_wrapper_string = uuid.uuid4().hex
         self.node_id = node_id
         self.level = level
         self.process_definitions_directory = process_definitions_directory
-        self.node_varname_prefix = node_varname_prefix
+        self.node_varname_prefix = "node_"
 
         if self.is_process_defined(process_id):
             self.process_id = process_id
@@ -71,6 +70,7 @@ class Node:
             "save_result": SaveResultNode,
             "merge_cubes": MergeCubesNode,
             "if": IfNode,
+            "apply": ApplyNode,
         }
         if class_types_for_process.get(process_id):
             self.__class__ = class_types_for_process[process_id]
@@ -222,3 +222,26 @@ class MergeCubesNode(Node):
 class IfNode(Node):
     def get_process_function_name(self):
         return "_if"
+
+
+class ApplyNode(Node):
+    def is_process_defined(self, process_id):
+        return True
+
+    def write_process(self):
+        newline = "\n"
+        tab = "\t"
+        return f"""
+function apply(arguments) {{  
+
+   function process(arguments) {{
+    {newline.join(node.write_function() for node in self.child_nodes)}
+    {newline.join(node.write_call() for node in self.child_nodes)}
+        return {self.child_nodes[-1].node_varname_prefix + self.child_nodes[-1].node_id};
+    }}
+    const {{data, dimension}} = arguments; 
+    const newData = data.clone()
+    newData.apply(process)
+    return newData;
+}}
+"""
